@@ -1,11 +1,9 @@
-cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale = TRUE, rotation="none",nstart=10,smartStart=NULL,seed=1234)
+cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale = TRUE, rotation="none",nstart=100,smartStart=NULL,seed=1234)
 {
-  #require(psych)
-  #  source("orth.r")
-  #  source("EmptyKmeans.r")
-  
   #NOTE: FactorialKM needs smartstart k-means or else to perform well
   #FIX: K=2, d=2 does not work for RKM
+  method <- match.arg(method, c("RKM", "rkm","rKM","FKM", "fkm","fKM"), several.ok = T)[1]
+  method <- toupper(method)
   
   #  If alpha = .5 gives RKM, alpha=1 PCA and alpha =0  FKM. 
   if (is.null(alpha) == TRUE)
@@ -24,7 +22,7 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale
   n = dim(data)[1]
   m = dim(data)[2]
   conv=1e-6  # convergence criterion
-  func={}; index={}; AA = {}; FF = {}; YY = {}; UU={}
+  func={}; AA = {}; FF = {}; YY = {}; UU={}
   for (run in c(1:nstart)) {
     
     # Starting method
@@ -50,7 +48,6 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale
     fold = f + 2 * conv*f
     iter = 0
     #iterative part
-   
     while (f<fold-conv*f) {
       fold=f
       iter=iter+1
@@ -73,9 +70,7 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale
       Y = pseudoinverse(t(U)%*%U)%*%t(U)%*%G
       # criterion
       f = alpha*ssq(data - G%*%t(A))+(1-alpha)*ssq(data%*%A-U%*%Y)
-  
     }
-   
     func[run] = f
     #fpXunc[run]=fpX
     FF[[run]] = G
@@ -90,18 +85,18 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale
   U=UU[[mi]]
   cluID = apply(U,1,which.max)
   
-  csize = round((table(cluID)/sum( table(cluID)))*100,digits=2)
-  aa = sort(csize,decreasing = TRUE)
+  #csize = round((table(cluID)/sum( table(cluID)))*100,digits=2)
+  size = table(cluID)
+  aa = sort(size,decreasing = TRUE)
   cluID = mapvalues(cluID, from = as.integer(names(aa)), to = as.integer(names(table(cluID))))
   #reorder centroids
   centroid = YY[[mi]]
   centroid = centroid[as.integer(names(aa)),]
   #######################
   
- 
   ### rotation options ###
-  if (rotation == "varimax") {
-    AA[[mi]] = varimax(AA[[mi]])$loadings
+  if (rotation == "varimax") { #with Kaiser Normalization
+    AA[[mi]] = varimax(AA[[mi]])$loadings[1:m,1:ndim]
     FF[[mi]] = data%*%AA[[mi]]
     #update center
     centroid = pseudoinverse(t(U)%*%U)%*%t(U)%*%FF[[mi]] 
@@ -135,7 +130,7 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale
   names(cluID) = rownames(data) 
   out$cluID = cluID #apply(U,1,which.max)
   out$criterion = func[mi]
-  out$csize = round((table(cluID)/sum(table(cluID)))*100,digits=1)
+  out$size = as.integer(aa) #round((table(cluID)/sum(table(cluID)))*100,digits=1)
   out$odata = data.frame(odata)
   out$scale = scale
   out$center = center
@@ -146,4 +141,4 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method="RKM",center = TRUE, scale
 
 ssq = function(a) {
   t(as.vector(c(as.matrix(a))))%*%as.vector(c(as.matrix(a)))
-}
+}
\ No newline at end of file
